@@ -3,12 +3,12 @@ as_list_unnamed_default <- function(x, ...) {
   x <- as.list(x)
   names <- names(x)
   attributes(x) <- NULL
-  if(!is.null(names))
+  if (!is.null(names)) {
     names(x) <- names
+  }
   x
 }
 
 par_pattern <- function() {
   "[[:alpha:]][[:alnum:]._]*"
 }
-
